Class: Google::Cloud::AuditManager::V1::AuditScopeReport

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/auditmanager/v1/auditmanager.rb

Overview

The audit scope report.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Identifier. The name of this Audit Report, in the format of scope given in request.

Returns:

  • (::String)

    Identifier. The name of this Audit Report, in the format of scope given in request.



297
298
299
300
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 297

class AuditScopeReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scope_report_contents::String

Returns The audit scope report content in byte format.

Returns:

  • (::String)

    The audit scope report content in byte format.



297
298
299
300
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 297

class AuditScopeReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end