Class: Google::Cloud::AuditManager::V1::ControlDetails
- Inherits:
-
Object
- Object
- Google::Cloud::AuditManager::V1::ControlDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/auditmanager/v1/auditmanager.rb
Overview
The evaluation details for a control.
Instance Attribute Summary collapse
-
#compliance_state ⇒ ::Google::Cloud::AuditManager::V1::ComplianceState
readonly
Output only.
-
#control ⇒ ::Google::Cloud::AuditManager::V1::Control
The control for which the findings are being reported.
-
#control_report_summary ⇒ ::Google::Cloud::AuditManager::V1::ReportSummary
Report summary with compliance, violation counts etc.
Instance Attribute Details
#compliance_state ⇒ ::Google::Cloud::AuditManager::V1::ComplianceState (readonly)
Returns Output only. Overall status of the findings for the control.
588 589 590 591 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 588 class ControlDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#control ⇒ ::Google::Cloud::AuditManager::V1::Control
Returns The control for which the findings are being reported.
588 589 590 591 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 588 class ControlDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#control_report_summary ⇒ ::Google::Cloud::AuditManager::V1::ReportSummary
Returns Report summary with compliance, violation counts etc.
588 589 590 591 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 588 class ControlDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |