Class: Google::Cloud::AuditManager::V1::EnrollResourceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/auditmanager/v1/auditmanager.rb

Overview

Request message to subscribe the Audit Manager service for given resource.

Defined Under Namespace

Classes: EligibleDestination

Instance Attribute Summary collapse

Instance Attribute Details

#destinations::Array<::Google::Cloud::AuditManager::V1::EnrollResourceRequest::EligibleDestination>

Returns Required. List of destination among which customer can choose to upload their reports during the audit process. While enrolling at a organization/folder level, customer can choose Cloud storage bucket in any project. If the audit is triggered at project level using the service agent at organization/folder level, all the destination options associated with respective organization/folder level service agent will be available to auditing projects.

Returns:

  • (::Array<::Google::Cloud::AuditManager::V1::EnrollResourceRequest::EligibleDestination>)

    Required. List of destination among which customer can choose to upload their reports during the audit process. While enrolling at a organization/folder level, customer can choose Cloud storage bucket in any project. If the audit is triggered at project level using the service agent at organization/folder level, all the destination options associated with respective organization/folder level service agent will be available to auditing projects.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 41

class EnrollResourceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The destination details where the audit report must be uploaded.
  # @!attribute [rw] eligible_gcs_bucket
  #   @return [::String]
  #     The Cloud Storage bucket location where the audit report and evidences
  #     can be uploaded during the `GenerateAuditReport` API call.
  class EligibleDestination
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#scope::String

Returns Required. The resource to be enrolled to the audit manager. Scope format should be resource_type/resource_identifier Eg: projects/{project}/locations/{location}, folders/{folder}/locations/{location} organizations/{organization}/locations/{location}.

Returns:

  • (::String)

    Required. The resource to be enrolled to the audit manager. Scope format should be resource_type/resource_identifier Eg: projects/{project}/locations/{location}, folders/{folder}/locations/{location} organizations/{organization}/locations/{location}



41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 41

class EnrollResourceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The destination details where the audit report must be uploaded.
  # @!attribute [rw] eligible_gcs_bucket
  #   @return [::String]
  #     The Cloud Storage bucket location where the audit report and evidences
  #     can be uploaded during the `GenerateAuditReport` API call.
  class EligibleDestination
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end