Class: Google::Cloud::AuditManager::V1::EnrollResourceRequest::EligibleDestination

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/auditmanager/v1/auditmanager.rb

Overview

The destination details where the audit report must be uploaded.

Instance Attribute Summary collapse

Instance Attribute Details

#eligible_gcs_bucket::String

Returns The Cloud Storage bucket location where the audit report and evidences can be uploaded during the GenerateAuditReport API call.

Returns:

  • (::String)

    The Cloud Storage bucket location where the audit report and evidences can be uploaded during the GenerateAuditReport API call.



50
51
52
53
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 50

class EligibleDestination
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end