Class: Google::Cloud::AuditManager::V1::GenerateAuditReportRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/auditmanager/v1/auditmanager.rb

Overview

Message for requesting the Audit Report.

Defined Under Namespace

Modules: AuditReportFormat

Instance Attribute Summary collapse

Instance Attribute Details

#compliance_framework::String

Returns Required. Compliance framework against which the Report must be generated.

Returns:

  • (::String)

    Required. Compliance framework against which the Report must be generated.



110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 110

class GenerateAuditReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The options for the audit report format.
  module AuditReportFormat
    # Unspecified. Invalid state.
    AUDIT_REPORT_FORMAT_UNSPECIFIED = 0

    # Audit Report creation format is Open Document.
    AUDIT_REPORT_FORMAT_ODF = 1
  end
end

#compliance_standard::String

Returns Required. Compliance Standard against which the Scope Report must be generated. Eg: FEDRAMP_MODERATE.

Returns:

  • (::String)

    Required. Compliance Standard against which the Scope Report must be generated. Eg: FEDRAMP_MODERATE



110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 110

class GenerateAuditReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The options for the audit report format.
  module AuditReportFormat
    # Unspecified. Invalid state.
    AUDIT_REPORT_FORMAT_UNSPECIFIED = 0

    # Audit Report creation format is Open Document.
    AUDIT_REPORT_FORMAT_ODF = 1
  end
end

#gcs_uri::String

Returns Destination Cloud storage bucket where report and evidence must be uploaded. The Cloud storage bucket provided here must be selected among the buckets entered during the enrollment process.

Returns:

  • (::String)

    Destination Cloud storage bucket where report and evidence must be uploaded. The Cloud storage bucket provided here must be selected among the buckets entered during the enrollment process.



110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 110

class GenerateAuditReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The options for the audit report format.
  module AuditReportFormat
    # Unspecified. Invalid state.
    AUDIT_REPORT_FORMAT_UNSPECIFIED = 0

    # Audit Report creation format is Open Document.
    AUDIT_REPORT_FORMAT_ODF = 1
  end
end

#report_format::Google::Cloud::AuditManager::V1::GenerateAuditReportRequest::AuditReportFormat

Returns Required. The format in which the audit report should be created.

Returns:



110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 110

class GenerateAuditReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The options for the audit report format.
  module AuditReportFormat
    # Unspecified. Invalid state.
    AUDIT_REPORT_FORMAT_UNSPECIFIED = 0

    # Audit Report creation format is Open Document.
    AUDIT_REPORT_FORMAT_ODF = 1
  end
end

#scope::String

Returns Required. Scope for which the AuditScopeReport is required. Must be of format resource_type/resource_identifier Eg: projects/{project}/locations/{location}, folders/{folder}/locations/{location}.

Returns:

  • (::String)

    Required. Scope for which the AuditScopeReport is required. Must be of format resource_type/resource_identifier Eg: projects/{project}/locations/{location}, folders/{folder}/locations/{location}



110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 110

class GenerateAuditReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The options for the audit report format.
  module AuditReportFormat
    # Unspecified. Invalid state.
    AUDIT_REPORT_FORMAT_UNSPECIFIED = 0

    # Audit Report creation format is Open Document.
    AUDIT_REPORT_FORMAT_ODF = 1
  end
end