Class: Google::Cloud::AuditManager::V1::ListControlsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/auditmanager/v1/auditmanager.rb

Overview

Message for requesting all the controls for a compliance standard.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of resources to return.

Returns:

  • (::Integer)

    Optional. The maximum number of resources to return.



218
219
220
221
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 218

class ListControlsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The next_page_token value returned from a previous List request, if any.

Returns:

  • (::String)

    Optional. The next_page_token value returned from a previous List request, if any.



218
219
220
221
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 218

class ListControlsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Format projects/{project}/locations/{location}/standards/{standard}, folders/{folder}/locations/{location}/standards/{standard}.

Returns:

  • (::String)

    Required. Format projects/{project}/locations/{location}/standards/{standard}, folders/{folder}/locations/{location}/standards/{standard}



218
219
220
221
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 218

class ListControlsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end