Class: Google::Cloud::AuditManager::V1::ListControlsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/auditmanager/v1/auditmanager.rb

Overview

Response message with all the controls for a compliance standard.

Instance Attribute Summary collapse

Instance Attribute Details

#controls::Array<::Google::Cloud::AuditManager::V1::Control> (readonly)

Returns Output only. The controls for the compliance standard.

Returns:



230
231
232
233
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 230

class ListControlsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String (readonly)

Returns Output only. The token to retrieve the next page of results.

Returns:

  • (::String)

    Output only. The token to retrieve the next page of results.



230
231
232
233
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 230

class ListControlsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end