Class: Google::Cloud::AuditManager::V1::ReportGenerationProgress

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/auditmanager/v1/auditmanager.rb

Overview

The ReportGenerationProgress is part of google.longrunning.Operation returned to the client for every GetOperation request.

Instance Attribute Summary collapse

Instance Attribute Details

#audit_report::String (readonly)

Returns Output only. The name of the audit report.

Returns:

  • (::String)

    Output only. The name of the audit report.



271
272
273
274
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 271

class ReportGenerationProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#destination_gcs_bucket::String (readonly)

Returns Output only. The Cloud Storage bucket where the audit report will be uploaded once the evaluation process is completed.

Returns:

  • (::String)

    Output only. The Cloud Storage bucket where the audit report will be uploaded once the evaluation process is completed.



271
272
273
274
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 271

class ReportGenerationProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#evaluation_percent_complete::Float

Returns Shows the progress of the CESS service evaluation process. The progress is defined in terms of percentage complete and is being fetched from the CESS service.

Returns:

  • (::Float)

    Shows the progress of the CESS service evaluation process. The progress is defined in terms of percentage complete and is being fetched from the CESS service.



271
272
273
274
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 271

class ReportGenerationProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#failure_reason::String (readonly)

Returns Output only. States the reason of failure during the audit report generation process. This field is set only if the state attribute is OPERATION_STATE_FAILED.

Returns:

  • (::String)

    Output only. States the reason of failure during the audit report generation process. This field is set only if the state attribute is OPERATION_STATE_FAILED.



271
272
273
274
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 271

class ReportGenerationProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#report_generation_percent_complete::Float

Returns Shows the report generation progress of the CESS Result Processor Service. The // progress is defined in terms of percentage complete and is being fetched from the CESS service. If report_generation_in_progress is non zero then evaluation_percent_complete will be 100%.

Returns:

  • (::Float)

    Shows the report generation progress of the CESS Result Processor Service. The // progress is defined in terms of percentage complete and is being fetched from the CESS service. If report_generation_in_progress is non zero then evaluation_percent_complete will be 100%.



271
272
273
274
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 271

class ReportGenerationProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#report_uploading_percent_complete::Float

Returns Shows the report uploading progress of the CESS Result Processor Service. The progress is defined in terms of percentage complete and is being fetched from the CESS service. If report_uploading_in_progress is non zero then evaluation_percent_complete and report_generation_percent_complete will be 100%.

Returns:

  • (::Float)

    Shows the report uploading progress of the CESS Result Processor Service. The progress is defined in terms of percentage complete and is being fetched from the CESS service. If report_uploading_in_progress is non zero then evaluation_percent_complete and report_generation_percent_complete will be 100%.



271
272
273
274
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 271

class ReportGenerationProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#state::Google::Cloud::AuditManager::V1::OperationState (readonly)

Returns Output only. The current state of execution for report generation.

Returns:



271
272
273
274
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 271

class ReportGenerationProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end