Class: Google::Cloud::AuditManager::V1::ReportSummary
- Inherits:
-
Object
- Object
- Google::Cloud::AuditManager::V1::ReportSummary
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/auditmanager/v1/auditmanager.rb
Overview
The additional information for an audit operation.
Instance Attribute Summary collapse
-
#compliant_count ⇒ ::Integer
Number of compliant checks.
-
#error_count ⇒ ::Integer
Number of checks that could not be performed due to errors.
-
#manual_review_needed_count ⇒ ::Integer
Number of checks with "manual review needed" status.
-
#total_count ⇒ ::Integer
Total number of checks.
-
#violation_count ⇒ ::Integer
Number of checks with violations.
Instance Attribute Details
#compliant_count ⇒ ::Integer
Returns Number of compliant checks.
573 574 575 576 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 573 class ReportSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error_count ⇒ ::Integer
Returns Number of checks that could not be performed due to errors.
573 574 575 576 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 573 class ReportSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#manual_review_needed_count ⇒ ::Integer
Returns Number of checks with "manual review needed" status.
573 574 575 576 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 573 class ReportSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_count ⇒ ::Integer
Returns Total number of checks.
573 574 575 576 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 573 class ReportSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#violation_count ⇒ ::Integer
Returns Number of checks with violations.
573 574 575 576 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 573 class ReportSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |