Class: Google::Cloud::AuditManager::V1::ResourceEnrollmentStatus
- Inherits:
-
Object
- Object
- Google::Cloud::AuditManager::V1::ResourceEnrollmentStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/auditmanager/v1/auditmanager.rb
Overview
A resource with its enrollment status.
Defined Under Namespace
Modules: ResourceEnrollmentState
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
readonly
Output only.
-
#enrolled ⇒ ::Boolean
readonly
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#enrollment ⇒ ::Google::Cloud::AuditManager::V1::Enrollment
readonly
Output only.
-
#enrollment_state ⇒ ::Google::Cloud::AuditManager::V1::ResourceEnrollmentStatus::ResourceEnrollmentState
readonly
Output only.
-
#name ⇒ ::String
Identifier.
Instance Attribute Details
#display_name ⇒ ::String (readonly)
Returns Output only. Display name of the project/folder/organization.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 351 class ResourceEnrollmentStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different enrollment states of a resource. module ResourceEnrollmentState # Unspecified. Invalid state. RESOURCE_ENROLLMENT_STATE_UNSPECIFIED = 0 # Not enrolled. NOT_ENROLLED = 1 # Resource is not enrolled but the parent is enrolled. INHERITED = 2 # Enrolled. ENROLLED = 3 end end |
#enrolled ⇒ ::Boolean (readonly)
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Output only. Is resource enrolled.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 351 class ResourceEnrollmentStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different enrollment states of a resource. module ResourceEnrollmentState # Unspecified. Invalid state. RESOURCE_ENROLLMENT_STATE_UNSPECIFIED = 0 # Not enrolled. NOT_ENROLLED = 1 # Resource is not enrolled but the parent is enrolled. INHERITED = 2 # Enrolled. ENROLLED = 3 end end |
#enrollment ⇒ ::Google::Cloud::AuditManager::V1::Enrollment (readonly)
Returns Output only. Enrollment which contains enrolled destination details for a resource.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 351 class ResourceEnrollmentStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different enrollment states of a resource. module ResourceEnrollmentState # Unspecified. Invalid state. RESOURCE_ENROLLMENT_STATE_UNSPECIFIED = 0 # Not enrolled. NOT_ENROLLED = 1 # Resource is not enrolled but the parent is enrolled. INHERITED = 2 # Enrolled. ENROLLED = 3 end end |
#enrollment_state ⇒ ::Google::Cloud::AuditManager::V1::ResourceEnrollmentStatus::ResourceEnrollmentState (readonly)
Returns Output only. Enrollment state of the resource.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 351 class ResourceEnrollmentStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different enrollment states of a resource. module ResourceEnrollmentState # Unspecified. Invalid state. RESOURCE_ENROLLMENT_STATE_UNSPECIFIED = 0 # Not enrolled. NOT_ENROLLED = 1 # Resource is not enrolled but the parent is enrolled. INHERITED = 2 # Enrolled. ENROLLED = 3 end end |
#name ⇒ ::String
Returns Identifier. The name of this resource.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 351 class ResourceEnrollmentStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different enrollment states of a resource. module ResourceEnrollmentState # Unspecified. Invalid state. RESOURCE_ENROLLMENT_STATE_UNSPECIFIED = 0 # Not enrolled. NOT_ENROLLED = 1 # Resource is not enrolled but the parent is enrolled. INHERITED = 2 # Enrolled. ENROLLED = 3 end end |