Class: Google::Cloud::AuditManager::V1::AuditReport
- Inherits:
-
Object
- Object
- Google::Cloud::AuditManager::V1::AuditReport
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/auditmanager/v1/auditmanager.rb
Overview
An audit report.
Defined Under Namespace
Modules: ReportGenerationState
Instance Attribute Summary collapse
-
#compliance_framework ⇒ ::String
readonly
Output only.
-
#compliance_standard ⇒ ::String
readonly
Output only.
-
#control_details ⇒ ::Array<::Google::Cloud::AuditManager::V1::ControlDetails>
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#destination_details ⇒ ::Google::Cloud::AuditManager::V1::DestinationDetails
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#operation_id ⇒ ::String
readonly
Output only.
-
#report_generation_state ⇒ ::Google::Cloud::AuditManager::V1::AuditReport::ReportGenerationState
readonly
Output only.
-
#report_summary ⇒ ::Google::Cloud::AuditManager::V1::ReportSummary
readonly
Output only.
-
#scope ⇒ ::String
readonly
Output only.
-
#scope_id ⇒ ::String
readonly
Output only.
Instance Attribute Details
#compliance_framework ⇒ ::String (readonly)
Returns Output only. Compliance Framework of Audit Report.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 407 class AuditReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different states of the Audit Manager report generation. module ReportGenerationState # Unspecified. Invalid state. REPORT_GENERATION_STATE_UNSPECIFIED = 0 # Audit report generation process is in progress, ie. operation state is # neither OPERATION_STATE_DONE nor OPERATION_STATE_FAILED. IN_PROGRESS = 1 # Audit report generation process is completed. Operation state is # OPERATION_STATE_DONE. COMPLETED = 2 # Audit report generation process has failed. Operation state is # OPERATION_STATE_FAILED. FAILED = 3 # Audit report generation process has completed. But report summary is # unknown. This is valid for older reports. SUMMARY_UNKNOWN = 4 end end |
#compliance_standard ⇒ ::String (readonly)
Returns Output only. Compliance Standard.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 407 class AuditReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different states of the Audit Manager report generation. module ReportGenerationState # Unspecified. Invalid state. REPORT_GENERATION_STATE_UNSPECIFIED = 0 # Audit report generation process is in progress, ie. operation state is # neither OPERATION_STATE_DONE nor OPERATION_STATE_FAILED. IN_PROGRESS = 1 # Audit report generation process is completed. Operation state is # OPERATION_STATE_DONE. COMPLETED = 2 # Audit report generation process has failed. Operation state is # OPERATION_STATE_FAILED. FAILED = 3 # Audit report generation process has completed. But report summary is # unknown. This is valid for older reports. SUMMARY_UNKNOWN = 4 end end |
#control_details ⇒ ::Array<::Google::Cloud::AuditManager::V1::ControlDetails> (readonly)
Returns Output only. The overall status of controls.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 407 class AuditReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different states of the Audit Manager report generation. module ReportGenerationState # Unspecified. Invalid state. REPORT_GENERATION_STATE_UNSPECIFIED = 0 # Audit report generation process is in progress, ie. operation state is # neither OPERATION_STATE_DONE nor OPERATION_STATE_FAILED. IN_PROGRESS = 1 # Audit report generation process is completed. Operation state is # OPERATION_STATE_DONE. COMPLETED = 2 # Audit report generation process has failed. Operation state is # OPERATION_STATE_FAILED. FAILED = 3 # Audit report generation process has completed. But report summary is # unknown. This is valid for older reports. SUMMARY_UNKNOWN = 4 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Creation time of the audit report.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 407 class AuditReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different states of the Audit Manager report generation. module ReportGenerationState # Unspecified. Invalid state. REPORT_GENERATION_STATE_UNSPECIFIED = 0 # Audit report generation process is in progress, ie. operation state is # neither OPERATION_STATE_DONE nor OPERATION_STATE_FAILED. IN_PROGRESS = 1 # Audit report generation process is completed. Operation state is # OPERATION_STATE_DONE. COMPLETED = 2 # Audit report generation process has failed. Operation state is # OPERATION_STATE_FAILED. FAILED = 3 # Audit report generation process has completed. But report summary is # unknown. This is valid for older reports. SUMMARY_UNKNOWN = 4 end end |
#destination_details ⇒ ::Google::Cloud::AuditManager::V1::DestinationDetails (readonly)
Returns Output only. The location where the generated report will be uploaded.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 407 class AuditReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different states of the Audit Manager report generation. module ReportGenerationState # Unspecified. Invalid state. REPORT_GENERATION_STATE_UNSPECIFIED = 0 # Audit report generation process is in progress, ie. operation state is # neither OPERATION_STATE_DONE nor OPERATION_STATE_FAILED. IN_PROGRESS = 1 # Audit report generation process is completed. Operation state is # OPERATION_STATE_DONE. COMPLETED = 2 # Audit report generation process has failed. Operation state is # OPERATION_STATE_FAILED. FAILED = 3 # Audit report generation process has completed. But report summary is # unknown. This is valid for older reports. SUMMARY_UNKNOWN = 4 end end |
#name ⇒ ::String
Returns Identifier. The name of this Audit Report, in the format of scope given in request.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 407 class AuditReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different states of the Audit Manager report generation. module ReportGenerationState # Unspecified. Invalid state. REPORT_GENERATION_STATE_UNSPECIFIED = 0 # Audit report generation process is in progress, ie. operation state is # neither OPERATION_STATE_DONE nor OPERATION_STATE_FAILED. IN_PROGRESS = 1 # Audit report generation process is completed. Operation state is # OPERATION_STATE_DONE. COMPLETED = 2 # Audit report generation process has failed. Operation state is # OPERATION_STATE_FAILED. FAILED = 3 # Audit report generation process has completed. But report summary is # unknown. This is valid for older reports. SUMMARY_UNKNOWN = 4 end end |
#operation_id ⇒ ::String (readonly)
Returns Output only. ClientOperationId.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 407 class AuditReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different states of the Audit Manager report generation. module ReportGenerationState # Unspecified. Invalid state. REPORT_GENERATION_STATE_UNSPECIFIED = 0 # Audit report generation process is in progress, ie. operation state is # neither OPERATION_STATE_DONE nor OPERATION_STATE_FAILED. IN_PROGRESS = 1 # Audit report generation process is completed. Operation state is # OPERATION_STATE_DONE. COMPLETED = 2 # Audit report generation process has failed. Operation state is # OPERATION_STATE_FAILED. FAILED = 3 # Audit report generation process has completed. But report summary is # unknown. This is valid for older reports. SUMMARY_UNKNOWN = 4 end end |
#report_generation_state ⇒ ::Google::Cloud::AuditManager::V1::AuditReport::ReportGenerationState (readonly)
Returns Output only. The state of Audit Report Generation.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 407 class AuditReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different states of the Audit Manager report generation. module ReportGenerationState # Unspecified. Invalid state. REPORT_GENERATION_STATE_UNSPECIFIED = 0 # Audit report generation process is in progress, ie. operation state is # neither OPERATION_STATE_DONE nor OPERATION_STATE_FAILED. IN_PROGRESS = 1 # Audit report generation process is completed. Operation state is # OPERATION_STATE_DONE. COMPLETED = 2 # Audit report generation process has failed. Operation state is # OPERATION_STATE_FAILED. FAILED = 3 # Audit report generation process has completed. But report summary is # unknown. This is valid for older reports. SUMMARY_UNKNOWN = 4 end end |
#report_summary ⇒ ::Google::Cloud::AuditManager::V1::ReportSummary (readonly)
Returns Output only. Report summary with compliance, violation counts etc.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 407 class AuditReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different states of the Audit Manager report generation. module ReportGenerationState # Unspecified. Invalid state. REPORT_GENERATION_STATE_UNSPECIFIED = 0 # Audit report generation process is in progress, ie. operation state is # neither OPERATION_STATE_DONE nor OPERATION_STATE_FAILED. IN_PROGRESS = 1 # Audit report generation process is completed. Operation state is # OPERATION_STATE_DONE. COMPLETED = 2 # Audit report generation process has failed. Operation state is # OPERATION_STATE_FAILED. FAILED = 3 # Audit report generation process has completed. But report summary is # unknown. This is valid for older reports. SUMMARY_UNKNOWN = 4 end end |
#scope ⇒ ::String (readonly)
Returns Output only. The parent scope on which the report was generated.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 407 class AuditReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different states of the Audit Manager report generation. module ReportGenerationState # Unspecified. Invalid state. REPORT_GENERATION_STATE_UNSPECIFIED = 0 # Audit report generation process is in progress, ie. operation state is # neither OPERATION_STATE_DONE nor OPERATION_STATE_FAILED. IN_PROGRESS = 1 # Audit report generation process is completed. Operation state is # OPERATION_STATE_DONE. COMPLETED = 2 # Audit report generation process has failed. Operation state is # OPERATION_STATE_FAILED. FAILED = 3 # Audit report generation process has completed. But report summary is # unknown. This is valid for older reports. SUMMARY_UNKNOWN = 4 end end |
#scope_id ⇒ ::String (readonly)
Returns Output only. The ID/ Number for the scope on which the audit report was generated.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 407 class AuditReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The different states of the Audit Manager report generation. module ReportGenerationState # Unspecified. Invalid state. REPORT_GENERATION_STATE_UNSPECIFIED = 0 # Audit report generation process is in progress, ie. operation state is # neither OPERATION_STATE_DONE nor OPERATION_STATE_FAILED. IN_PROGRESS = 1 # Audit report generation process is completed. Operation state is # OPERATION_STATE_DONE. COMPLETED = 2 # Audit report generation process has failed. Operation state is # OPERATION_STATE_FAILED. FAILED = 3 # Audit report generation process has completed. But report summary is # unknown. This is valid for older reports. SUMMARY_UNKNOWN = 4 end end |