Class: Google::Cloud::AuditManager::V1::Control
- Inherits:
-
Object
- Object
- Google::Cloud::AuditManager::V1::Control
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/auditmanager/v1/auditmanager.rb
Overview
A control.
Defined Under Namespace
Modules: Family
Instance Attribute Summary collapse
-
#control_family ⇒ ::Google::Cloud::AuditManager::V1::ControlFamily
readonly
Output only.
-
#customer_responsibility_description ⇒ ::String
readonly
Output only.
-
#customer_responsibility_implementation ⇒ ::String
readonly
Output only.
-
#description ⇒ ::String
readonly
Output only.
-
#display_name ⇒ ::String
readonly
Output only.
-
#family ⇒ ::Google::Cloud::AuditManager::V1::Control::Family
readonly
Output only.
-
#google_responsibility_description ⇒ ::String
readonly
Output only.
-
#google_responsibility_implementation ⇒ ::String
readonly
Output only.
-
#id ⇒ ::String
readonly
Output only.
-
#responsibility_type ⇒ ::String
readonly
Output only.
Instance Attribute Details
#control_family ⇒ ::Google::Cloud::AuditManager::V1::ControlFamily (readonly)
Returns Output only. Regulatory Family of the control E.g. Access Control.
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 483 class Control include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The family of the control. For example, Access Control. module Family # Unspecified. Invalid state. FAMILY_UNSPECIFIED = 0 # Access Control AC = 1 # Awareness and Training AT = 2 # Audit and Accountability AU = 3 # Certification, Accreditation and Security Assessments CA = 4 # Configuration Management CM = 5 # Contingency Planning CP = 6 # Identification and Authentication IA = 7 # Incident Response IR = 8 # Maintenance MA = 9 # Media Protection MP = 10 # Physical and Environmental Protection PE = 11 # Security Planning PL = 12 # Personnel Security PS = 13 # Risk Assessment RA = 14 # System Services and Acquisition SA = 15 # System and Communications Protection SC = 16 # System and Information Integrity SI = 17 # Supply Chain Risk Management SR = 18 end end |
#customer_responsibility_description ⇒ ::String (readonly)
Returns Output only. Description of the customer responsibility for implementing this control.
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 483 class Control include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The family of the control. For example, Access Control. module Family # Unspecified. Invalid state. FAMILY_UNSPECIFIED = 0 # Access Control AC = 1 # Awareness and Training AT = 2 # Audit and Accountability AU = 3 # Certification, Accreditation and Security Assessments CA = 4 # Configuration Management CM = 5 # Contingency Planning CP = 6 # Identification and Authentication IA = 7 # Incident Response IR = 8 # Maintenance MA = 9 # Media Protection MP = 10 # Physical and Environmental Protection PE = 11 # Security Planning PL = 12 # Personnel Security PS = 13 # Risk Assessment RA = 14 # System Services and Acquisition SA = 15 # System and Communications Protection SC = 16 # System and Information Integrity SI = 17 # Supply Chain Risk Management SR = 18 end end |
#customer_responsibility_implementation ⇒ ::String (readonly)
Returns Output only. Implementation of the customer responsibility for implementing this control.
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 483 class Control include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The family of the control. For example, Access Control. module Family # Unspecified. Invalid state. FAMILY_UNSPECIFIED = 0 # Access Control AC = 1 # Awareness and Training AT = 2 # Audit and Accountability AU = 3 # Certification, Accreditation and Security Assessments CA = 4 # Configuration Management CM = 5 # Contingency Planning CP = 6 # Identification and Authentication IA = 7 # Incident Response IR = 8 # Maintenance MA = 9 # Media Protection MP = 10 # Physical and Environmental Protection PE = 11 # Security Planning PL = 12 # Personnel Security PS = 13 # Risk Assessment RA = 14 # System Services and Acquisition SA = 15 # System and Communications Protection SC = 16 # System and Information Integrity SI = 17 # Supply Chain Risk Management SR = 18 end end |
#description ⇒ ::String (readonly)
Returns Output only. Regulatory control ask of the control.
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 483 class Control include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The family of the control. For example, Access Control. module Family # Unspecified. Invalid state. FAMILY_UNSPECIFIED = 0 # Access Control AC = 1 # Awareness and Training AT = 2 # Audit and Accountability AU = 3 # Certification, Accreditation and Security Assessments CA = 4 # Configuration Management CM = 5 # Contingency Planning CP = 6 # Identification and Authentication IA = 7 # Incident Response IR = 8 # Maintenance MA = 9 # Media Protection MP = 10 # Physical and Environmental Protection PE = 11 # Security Planning PL = 12 # Personnel Security PS = 13 # Risk Assessment RA = 14 # System Services and Acquisition SA = 15 # System and Communications Protection SC = 16 # System and Information Integrity SI = 17 # Supply Chain Risk Management SR = 18 end end |
#display_name ⇒ ::String (readonly)
Returns Output only. Display name of the control.
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 483 class Control include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The family of the control. For example, Access Control. module Family # Unspecified. Invalid state. FAMILY_UNSPECIFIED = 0 # Access Control AC = 1 # Awareness and Training AT = 2 # Audit and Accountability AU = 3 # Certification, Accreditation and Security Assessments CA = 4 # Configuration Management CM = 5 # Contingency Planning CP = 6 # Identification and Authentication IA = 7 # Incident Response IR = 8 # Maintenance MA = 9 # Media Protection MP = 10 # Physical and Environmental Protection PE = 11 # Security Planning PL = 12 # Personnel Security PS = 13 # Risk Assessment RA = 14 # System Services and Acquisition SA = 15 # System and Communications Protection SC = 16 # System and Information Integrity SI = 17 # Supply Chain Risk Management SR = 18 end end |
#family ⇒ ::Google::Cloud::AuditManager::V1::Control::Family (readonly)
Returns Output only. Group where the control belongs. E.g. Access Control.
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 483 class Control include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The family of the control. For example, Access Control. module Family # Unspecified. Invalid state. FAMILY_UNSPECIFIED = 0 # Access Control AC = 1 # Awareness and Training AT = 2 # Audit and Accountability AU = 3 # Certification, Accreditation and Security Assessments CA = 4 # Configuration Management CM = 5 # Contingency Planning CP = 6 # Identification and Authentication IA = 7 # Incident Response IR = 8 # Maintenance MA = 9 # Media Protection MP = 10 # Physical and Environmental Protection PE = 11 # Security Planning PL = 12 # Personnel Security PS = 13 # Risk Assessment RA = 14 # System Services and Acquisition SA = 15 # System and Communications Protection SC = 16 # System and Information Integrity SI = 17 # Supply Chain Risk Management SR = 18 end end |
#google_responsibility_description ⇒ ::String (readonly)
Returns Output only. Description of the google responsibility for implementing this control.
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 483 class Control include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The family of the control. For example, Access Control. module Family # Unspecified. Invalid state. FAMILY_UNSPECIFIED = 0 # Access Control AC = 1 # Awareness and Training AT = 2 # Audit and Accountability AU = 3 # Certification, Accreditation and Security Assessments CA = 4 # Configuration Management CM = 5 # Contingency Planning CP = 6 # Identification and Authentication IA = 7 # Incident Response IR = 8 # Maintenance MA = 9 # Media Protection MP = 10 # Physical and Environmental Protection PE = 11 # Security Planning PL = 12 # Personnel Security PS = 13 # Risk Assessment RA = 14 # System Services and Acquisition SA = 15 # System and Communications Protection SC = 16 # System and Information Integrity SI = 17 # Supply Chain Risk Management SR = 18 end end |
#google_responsibility_implementation ⇒ ::String (readonly)
Returns Output only. Implementation of the google responsibility for implementing this control.
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 483 class Control include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The family of the control. For example, Access Control. module Family # Unspecified. Invalid state. FAMILY_UNSPECIFIED = 0 # Access Control AC = 1 # Awareness and Training AT = 2 # Audit and Accountability AU = 3 # Certification, Accreditation and Security Assessments CA = 4 # Configuration Management CM = 5 # Contingency Planning CP = 6 # Identification and Authentication IA = 7 # Incident Response IR = 8 # Maintenance MA = 9 # Media Protection MP = 10 # Physical and Environmental Protection PE = 11 # Security Planning PL = 12 # Personnel Security PS = 13 # Risk Assessment RA = 14 # System Services and Acquisition SA = 15 # System and Communications Protection SC = 16 # System and Information Integrity SI = 17 # Supply Chain Risk Management SR = 18 end end |
#id ⇒ ::String (readonly)
Returns Output only. The control identifier used to fetch the findings. This is same as the control report name.
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 483 class Control include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The family of the control. For example, Access Control. module Family # Unspecified. Invalid state. FAMILY_UNSPECIFIED = 0 # Access Control AC = 1 # Awareness and Training AT = 2 # Audit and Accountability AU = 3 # Certification, Accreditation and Security Assessments CA = 4 # Configuration Management CM = 5 # Contingency Planning CP = 6 # Identification and Authentication IA = 7 # Incident Response IR = 8 # Maintenance MA = 9 # Media Protection MP = 10 # Physical and Environmental Protection PE = 11 # Security Planning PL = 12 # Personnel Security PS = 13 # Risk Assessment RA = 14 # System Services and Acquisition SA = 15 # System and Communications Protection SC = 16 # System and Information Integrity SI = 17 # Supply Chain Risk Management SR = 18 end end |
#responsibility_type ⇒ ::String (readonly)
Returns Output only. The type of responsibility for implementing this control. It can be google, customer or shared.
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 483 class Control include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The family of the control. For example, Access Control. module Family # Unspecified. Invalid state. FAMILY_UNSPECIFIED = 0 # Access Control AC = 1 # Awareness and Training AT = 2 # Audit and Accountability AU = 3 # Certification, Accreditation and Security Assessments CA = 4 # Configuration Management CM = 5 # Contingency Planning CP = 6 # Identification and Authentication IA = 7 # Incident Response IR = 8 # Maintenance MA = 9 # Media Protection MP = 10 # Physical and Environmental Protection PE = 11 # Security Planning PL = 12 # Personnel Security PS = 13 # Risk Assessment RA = 14 # System Services and Acquisition SA = 15 # System and Communications Protection SC = 16 # System and Information Integrity SI = 17 # Supply Chain Risk Management SR = 18 end end |