Class: Google::Cloud::AuditManager::V1::DestinationDetails
- Inherits:
-
Object
- Object
- Google::Cloud::AuditManager::V1::DestinationDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/auditmanager/v1/auditmanager.rb
Overview
The locations where the generated reports are saved.
Instance Attribute Summary collapse
-
#gcs_bucket_uri ⇒ ::String
The Cloud Storage bucket where the audit report is/will be uploaded.
Instance Attribute Details
#gcs_bucket_uri ⇒ ::String
Returns The Cloud Storage bucket where the audit report is/will be uploaded.
552 553 554 555 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 552 class DestinationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |