Class: Google::Cloud::AuditManager::V1::Enrollment
- Inherits:
-
Object
- Object
- Google::Cloud::AuditManager::V1::Enrollment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/auditmanager/v1/auditmanager.rb
Overview
The enrollment resource.
Instance Attribute Summary collapse
-
#destination_details ⇒ ::Array<::Google::Cloud::AuditManager::V1::DestinationDetails>
readonly
Output only.
-
#name ⇒ ::String
Identifier.
Instance Attribute Details
#destination_details ⇒ ::Array<::Google::Cloud::AuditManager::V1::DestinationDetails> (readonly)
Returns Output only. The locations where the generated reports can be uploaded.
284 285 286 287 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 284 class Enrollment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The name of this Enrollment, in the format of scope given in request.
284 285 286 287 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 284 class Enrollment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |