Class: Google::Cloud::AuditManager::V1::GenerateAuditScopeReportRequest
- Inherits:
-
Object
- Object
- Google::Cloud::AuditManager::V1::GenerateAuditScopeReportRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/auditmanager/v1/auditmanager.rb
Overview
Message for requesting audit scope report.
Defined Under Namespace
Modules: AuditScopeReportFormat
Instance Attribute Summary collapse
-
#compliance_framework ⇒ ::String
Required.
-
#compliance_standard ⇒ ::String
Required.
-
#report_format ⇒ ::Google::Cloud::AuditManager::V1::GenerateAuditScopeReportRequest::AuditScopeReportFormat
Required.
-
#scope ⇒ ::String
Required.
Instance Attribute Details
#compliance_framework ⇒ ::String
Returns Required. Compliance framework against which the Scope Report must be generated.
74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 74 class GenerateAuditScopeReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The options for the audit scope report format. module AuditScopeReportFormat # Unspecified. Invalid format. AUDIT_SCOPE_REPORT_FORMAT_UNSPECIFIED = 0 # Audit Scope Report creation format is Open Document. AUDIT_SCOPE_REPORT_FORMAT_ODF = 1 end end |
#compliance_standard ⇒ ::String
Returns Required. Compliance Standard against which the Scope Report must be generated. Eg: FEDRAMP_MODERATE.
74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 74 class GenerateAuditScopeReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The options for the audit scope report format. module AuditScopeReportFormat # Unspecified. Invalid format. AUDIT_SCOPE_REPORT_FORMAT_UNSPECIFIED = 0 # Audit Scope Report creation format is Open Document. AUDIT_SCOPE_REPORT_FORMAT_ODF = 1 end end |
#report_format ⇒ ::Google::Cloud::AuditManager::V1::GenerateAuditScopeReportRequest::AuditScopeReportFormat
Returns Required. The format in which the Scope report bytes should be returned.
74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 74 class GenerateAuditScopeReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The options for the audit scope report format. module AuditScopeReportFormat # Unspecified. Invalid format. AUDIT_SCOPE_REPORT_FORMAT_UNSPECIFIED = 0 # Audit Scope Report creation format is Open Document. AUDIT_SCOPE_REPORT_FORMAT_ODF = 1 end end |
#scope ⇒ ::String
Returns Required. Scope for which the AuditScopeReport is required. Must be of format resource_type/resource_identifier Eg: projects/{project}/locations/{location}, folders/{folder}/locations/{location}.
74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'proto_docs/google/cloud/auditmanager/v1/auditmanager.rb', line 74 class GenerateAuditScopeReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The options for the audit scope report format. module AuditScopeReportFormat # Unspecified. Invalid format. AUDIT_SCOPE_REPORT_FORMAT_UNSPECIFIED = 0 # Audit Scope Report creation format is Open Document. AUDIT_SCOPE_REPORT_FORMAT_ODF = 1 end end |