Module: Google::Cloud::AuditManager::V1::OperationState
- Defined in:
- proto_docs/google/cloud/auditmanager/v1/auditmanager.rb
Overview
The different execution states of the Audit Manager service.
Constant Summary collapse
- OPERATION_STATE_UNSPECIFIED =
Unspecified. Invalid state.
0- OPERATION_STATE_NOT_STARTED =
Audit report generation process has not started.
10- OPERATION_STATE_EVALUATION_IN_PROGRESS =
Audit Manager is currently evaluating the workloads against specific standard.
20- OPERATION_STATE_EVALUATION_DONE =
Audit Manager has completed Evaluation for the workload.
21- OPERATION_STATE_EVIDENCE_REPORT_GENERATION_IN_PROGRESS =
Audit Manager is creating audit report from the evaluated data.
30- OPERATION_STATE_EVIDENCE_REPORT_GENERATION_DONE =
Audit Manager has completed generation of the audit report.
31- OPERATION_STATE_EVIDENCE_UPLOAD_IN_PROGRESS =
Audit Manager is uploading the audit report and evidences to the customer provided destination.
40- OPERATION_STATE_DONE =
Audit report generation process is completed.
50- OPERATION_STATE_FAILED =
Audit report generation process has failed.
60